Approve Test - Image Enhance Preset Selection

## Add a Step

Insert After:
Step Type:

Select a step type, then click on frame slots below to capture from video

Before
Click to capture frame
Action
Click to capture & place tap
Tap at: Click on frame
Start: Click on frame
After
Click to capture frame

### Capture Frame

0:00 / 0:00

Scrub to desired moment and click Capture

Tap position: (0, 0)
Select BEFORE Frame
Scrub to the desired moment and click Capture
0:00 / 0:00
X: 50%
Y: 50%
Description (optional)

## Edit

Value